@@ -49,7 +49,7 @@ def issue_iterator_factory(jql, fields, expand):
                     yield issue
                 return
         except KeyError:
-            logging.error("Cache missed for JQL: " + jql)
+            logging.warning("Cache missed for JQL: " + jql)
             pass
         # no cache - need to actually go and fetch the data from JIRA
         finished = False
@@ -301,7 +301,7 @@ def issue_loops(issue, statuses, allLoops):
                                 break
                     lastKnownStatusIndex = statusIndex
                 except ValueError:
-                    logger.error("Unknown status: {}".format(history_item.to))
+                    logger.warning("Unknown status: {}".format(history_item.to))
             else:
                 # update of field different than status
                 #print history_item['field']
